@@ -45,8 +45,6 @@ def generate_bright_setup(hostname, head_node_sg_id, node_sg_id, existing_subnet
             "type": config["node_type"],
         },
         "extra_disks": [],
-        "access_key": config["aws_access_key_id"],
-        "secret_key": config["aws_secret_key"],
         "head_node_security_group_id": head_node_sg_id,
         "nodes_security_group_id": node_sg_id,
     }
@@ -72,4 +70,11 @@ def generate_bright_setup(hostname, head_node_sg_id, node_sg_id, existing_subnet
     if existing_subnet_ids:
         brightsetup["modules"]["brightsetup"]["amazon"]["existing_subnet_ids"] = existing_subnet_ids
 
+    if config["headnode_instance_profile"]:
+        brightsetup["modules"]["brightsetup"]["amazon"]["headnode_instance_profile"] = \
+            config["headnode_instance_profile"]
+    else:
+        brightsetup["modules"]["brightsetup"]["amazon"]["access_key"] = config["aws_access_key_id"]
+        brightsetup["modules"]["brightsetup"]["amazon"]["secret_key"] = config["aws_secret_key"]
+
     return brightsetup
