@@ -428,6 +428,13 @@ config_ns.add_parameter(
     advanced=True,
     help="Name of the placement group for the head node."
 )
+config_ns.add_parameter(
+    "headnode_instance_profile",
+    help_varname="PROFILE",
+    help="Instance profile to assign to the head node. Can be specified as short name or full ARN. The cluster will be "
+         "configured to obtain credentials from the meta-data endpoint. The values of the --aws-access-key-id and "
+         "--aws-secret-key settings will not be used by the head node CMDaemon."
+)
 
 
 def run_command():
@@ -482,8 +489,8 @@ class ClusterCreate(ClusterCommandBase):
             raise CODException(
                 f"Failed to find VPC with ID {config['existing_vpc_id']} in region {config['aws_region']}")
 
-        name = vpc.tags["Name"] if "Name" in vpc.tags else ""
-        log.debug(f"VPC '{config['existing_vpc_id']}' exists, good. Name: '{name}'.")
+        vpc_name = get_aws_tag(vpc.tags, "Name", "<name not set>")
+        log.debug(f"VPC '{config['existing_vpc_id']}' exists, good. Name: '{vpc_name}'.")
 
         # TODO(cloud-team): CM-32514 - remove the restrictions below for only 2 subnets.
         #  support more than 2 subnets (will require changes in cm-bright-setup)
